"""
Helper zum auslesen des KY-001 Temperatursensors
Der Code wurde abgewandelt von: https://sensorkit.joy-it.net/de/sensors/ky-001
SPDX-License-Identifier: MIT
"""


import glob
import time
import os

base_dir = '/sys/bus/w1/devices/'
device_folder = glob.glob(base_dir + os.sep + '28*')[0]
device_file = device_folder + '/w1_slave'

def read_temp_raw():
        f = open(device_file, 'r')
        lines = f.readlines()
        f.close()
        return lines

def read_temp():
    lines = read_temp_raw()
    while lines[0].strip()[-3:] != 'YES':
        time.sleep(0.2)
        lines = read_temp_raw()

    equals_pos = lines[1].find('t=')
    if equals_pos != -1:
        temp_string = lines[1][equals_pos + 2:]
        temp_c = float(temp_string) / 1000.0
        return temp_c

#Wenn die Datei direkt ausgeführt wird, wird die Temperatur jede Sekunde ausgegeben.
if __name__ == '__main__':
    while True:
        print("Temperature: {:.2f} C".format(read_temp()))
        time.sleep(1)